@@ -5,13 +5,15 @@ package Pinto::Action::Pull;
 use Moose;
 use MooseX::Types::Moose qw(Bool);
 
+use Module::CoreList;
+
 use Pinto::Types qw(Specs StackName StackDefault);
 
 use namespace::autoclean;
 
 #------------------------------------------------------------------------------
 
-our $VERSION = '0.056'; # VERSION
+our $VERSION = '0.057'; # VERSION
 
 #------------------------------------------------------------------------------
 
@@ -77,6 +79,11 @@ sub execute {
 sub _pull {
     my ($self, $target, $stack) = @_;
 
+    if ($target->isa('Pinto::PackageSpec') && $self->_is_core_package($target, $stack)) {
+        $self->debug("$target is part of the perl core.  Skipping it");
+        return;
+    }
+
     my ($dist, $did_pull) = $self->repos->find_or_pull(target => $target);
     my $did_register = $dist ? $dist->register(stack => $stack, pin => $self->pin) : undef;
 
@@ -91,6 +98,20 @@ sub _pull {
 
 #------------------------------------------------------------------------------
 
+sub _is_core_package {
+    my ($self, $pspec, $stack) = @_;
+
+    my $wanted_package = $pspec->name;
+    my $wanted_version = $pspec->version;
+
+    return if not exists $Module::CoreList::version{ $] }->{$wanted_package};
+
+    my $core_version = $Module::CoreList::version{ $] }->{$wanted_package};
+    return $core_version >= $wanted_version;
+}
+
+#------------------------------------------------------------------------------
+
 sub message_primer {
     my ($self) = @_;
 
@@ -121,7 +142,7 @@ Pinto::Action::Pull - Pull upstream distributions into the repository
 
 =head1 VERSION
 
-version 0.056
+version 0.057
 
 =head1 AUTHOR
 
